==> ratis-proto-2.0.0-sources.jar: org/apache/ratis/proto/FileTransferExampleServiceGrpc.java <==
package org.apache.ratis.proto;

import static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.generateFullMethodName;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncUnaryCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.blockingUnaryCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.futureUnaryCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnaryCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.33.0)",
    comments = "Source: Experiments.proto")
public final class FileTransferExampleServiceGrpc {

  private FileTransferExampleServiceGrpc() {}

  public static final String SERVICE_NAME = "ratis.experiments.FileTransferExampleService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
      org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod;

  @org.apache.ratis.thirdparty.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "sendData",
      requestType = org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto.class,
      responseType = org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto.class,
      methodType = org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
      org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod() {
    org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto, org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod;
    if ((getSendDataMethod = FileTransferExampleServiceGrpc.getSendDataMethod) == null) {
      synchronized (FileTransferExampleServiceGrpc.class) {
        if ((getSendDataMethod = FileTransferExampleServiceGrpc.getSendDataMethod) == null) {
          FileTransferExampleServiceGrpc.getSendDataMethod = getSendDataMethod =
              org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto, org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>newBuilder()
              .setType(org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "sendData"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto.getDefaultInstance()))
              .setResponseMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto.getDefaultInstance()))
              .setSchemaDescriptor(new FileTransferExampleServiceMethodDescriptorSupplier("sendData"))
              .build();
        }
      }
    }
    return getSendDataMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static FileTransferExampleServiceStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceStub>() {
        @java.lang.Override
        public FileTransferExampleServiceStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static FileTransferExampleServiceBlockingStub newBlockingStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceBlockingStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceBlockingStub>() {
        @java.lang.Override
        public FileTransferExampleServiceBlockingStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceBlockingStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static FileTransferExampleServiceFutureStub newFutureStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceFutureStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceFutureStub>() {
        @java.lang.Override
        public FileTransferExampleServiceFutureStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceFutureStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class FileTransferExampleServiceImplBase implements org.apache.ratis.thirdparty.io.grpc.BindableService {

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto> sendData(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> responseObserver) {
      return asyncUnimplementedStreamingCall(getSendDataMethod(), responseObserver);
    }

    @java.lang.Override public final org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition bindService() {
      return org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSendDataMethod(),
            asyncBidiStreamingCall(
              new MethodHandlers<
                org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
                org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>(
                  this, METHODID_SEND_DATA)))
          .build();
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractAsyncStub<FileTransferExampleServiceStub> {
    private FileTransferExampleServiceStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceStub(channel, callOptions);
    }

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto> sendData(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> responseObserver) {
      return asyncBidiStreamingCall(
          getChannel().newCall(getSendDataMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceBlockingStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractBlockingStub<FileTransferExampleServiceBlockingStub> {
    private FileTransferExampleServiceBlockingStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceBlockingStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceFutureStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractFutureStub<FileTransferExampleServiceFutureStub> {
    private FileTransferExampleServiceFutureStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceFutureStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SEND_DATA = 0;

  private static final class MethodHandlers<Req, Resp> implements
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final FileTransferExampleServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(FileTransferExampleServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req> invoke(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SEND_DATA:
          return (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req>) serviceImpl.sendData(
              (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class FileTransferExampleServiceBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoFileDescriptorSupplier, org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    FileTransferExampleServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.ratis.proto.ExperimentsProtos.getDescriptor();
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("FileTransferExampleService");
    }
  }

  private static final class FileTransferExampleServiceFileDescriptorSupplier
      extends FileTransferExampleServiceBaseDescriptorSupplier {
    FileTransferExampleServiceFileDescriptorSupplier() {}
  }

  private static final class FileTransferExampleServiceMethodDescriptorSupplier
      extends FileTransferExampleServiceBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    FileTransferExampleServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor serviceDescriptor;

  public static org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor getServiceDescriptor() {
    org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (FileTransferExampleServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new FileTransferExampleServiceFileDescriptorSupplier())
              .addMethod(getSendDataMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> ratis-proto-2.3.0-sources.jar: org/apache/ratis/proto/FileTransferExampleServiceGrpc.java <==
package org.apache.ratis.proto;

import static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.44.0)",
    comments = "Source: Experiments.proto")
@org.apache.ratis.thirdparty.io.grpc.stub.annotations.GrpcGenerated
public final class FileTransferExampleServiceGrpc {

  private FileTransferExampleServiceGrpc() {}

  public static final String SERVICE_NAME = "ratis.experiments.FileTransferExampleService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
      org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod;

  @org.apache.ratis.thirdparty.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "sendData",
      requestType = org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto.class,
      responseType = org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto.class,
      methodType = org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
      org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod() {
    org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto, org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> getSendDataMethod;
    if ((getSendDataMethod = FileTransferExampleServiceGrpc.getSendDataMethod) == null) {
      synchronized (FileTransferExampleServiceGrpc.class) {
        if ((getSendDataMethod = FileTransferExampleServiceGrpc.getSendDataMethod) == null) {
          FileTransferExampleServiceGrpc.getSendDataMethod = getSendDataMethod =
              org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto, org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>newBuilder()
              .setType(org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "sendData"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto.getDefaultInstance()))
              .setResponseMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto.getDefaultInstance()))
              .setSchemaDescriptor(new FileTransferExampleServiceMethodDescriptorSupplier("sendData"))
              .build();
        }
      }
    }
    return getSendDataMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static FileTransferExampleServiceStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceStub>() {
        @java.lang.Override
        public FileTransferExampleServiceStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static FileTransferExampleServiceBlockingStub newBlockingStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceBlockingStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceBlockingStub>() {
        @java.lang.Override
        public FileTransferExampleServiceBlockingStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceBlockingStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static FileTransferExampleServiceFutureStub newFutureStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceFutureStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<FileTransferExampleServiceFutureStub>() {
        @java.lang.Override
        public FileTransferExampleServiceFutureStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new FileTransferExampleServiceFutureStub(channel, callOptions);
        }
      };
    return FileTransferExampleServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class FileTransferExampleServiceImplBase implements org.apache.ratis.thirdparty.io.grpc.BindableService {

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto> sendData(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getSendDataMethod(), responseObserver);
    }

    @java.lang.Override public final org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition bindService() {
      return org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSendDataMethod(),
            org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
              new MethodHandlers<
                org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto,
                org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>(
                  this, METHODID_SEND_DATA)))
          .build();
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractAsyncStub<FileTransferExampleServiceStub> {
    private FileTransferExampleServiceStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceStub(channel, callOptions);
    }

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferMsgProto> sendData(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getSendDataMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceBlockingStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractBlockingStub<FileTransferExampleServiceBlockingStub> {
    private FileTransferExampleServiceBlockingStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceBlockingStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class FileTransferExampleServiceFutureStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractFutureStub<FileTransferExampleServiceFutureStub> {
    private FileTransferExampleServiceFutureStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected FileTransferExampleServiceFutureStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new FileTransferExampleServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SEND_DATA = 0;

  private static final class MethodHandlers<Req, Resp> implements
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final FileTransferExampleServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(FileTransferExampleServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req> invoke(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SEND_DATA:
          return (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req>) serviceImpl.sendData(
              (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.proto.ExperimentsProtos.TransferReplyProto>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class FileTransferExampleServiceBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoFileDescriptorSupplier, org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    FileTransferExampleServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.ratis.proto.ExperimentsProtos.getDescriptor();
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("FileTransferExampleService");
    }
  }

  private static final class FileTransferExampleServiceFileDescriptorSupplier
      extends FileTransferExampleServiceBaseDescriptorSupplier {
    FileTransferExampleServiceFileDescriptorSupplier() {}
  }

  private static final class FileTransferExampleServiceMethodDescriptorSupplier
      extends FileTransferExampleServiceBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    FileTransferExampleServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor serviceDescriptor;

  public static org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor getServiceDescriptor() {
    org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (FileTransferExampleServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new FileTransferExampleServiceFileDescriptorSupplier())
              .addMethod(getSendDataMethod())
              .build();
        }
      }
    }
    return result;
  }
}
